@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Nestoria::Search::MetadataResponse;
 {
-  $WebService::Nestoria::Search::MetadataResponse::VERSION = '1.021004';
+  $WebService::Nestoria::Search::MetadataResponse::VERSION = '1.021005';
 }
 
 =head1 NAME
@@ -12,7 +12,7 @@ WebService::Nestoria::Search::MetadataResponse - Container object for the result
 
 =head1 VERSION
 
-version 1.021004
+version 1.021005
 
 This package is used by WebService::Nestoria::Search and a WebService::Nestoria::Search::MetadataResponse object should never need to be explicitly created by the user.
 
@@ -29,7 +29,6 @@ sub new {
         my $name = $stat->{metadata_name};
         $self->{metadata}{$name} = $stat;
     }
-
     return bless $self, $class;
 }
 
@@ -76,20 +75,37 @@ Returns the average for properties which match the number of bedrooms, property
     );
     my $average_price = $metadata->get_average_price(%options);
 
-Rent prices are monthly. Prices for the UK are in GBP. Prices for Spain, Italy and Germany are in Euros. The earliest date available is October 2007.
+Rent prices are monthly. Prices are in local currency (EUR, GBP, INR, etc) 
+See http://www.nestoria.co.uk/help/api-metadata to see from when data is available for each country
 
-If you leave out the year and month parameters it will take the most recent available.
+If year and month are not supplied data for the most recent month available will be returned.
 
 =cut
 
 sub get_average_price {
     my $self = shift;
+    return $self->_get_info('avg_price', @_);
+}
+
+=head2 get_num_datapoints
+
+Called the same way as get_average_price, but instead returns the number of datapoints used to calculate the average.
+
+=cut
+
+sub get_num_datapoints {
+    my $self = shift;
+    return $self->_get_info('datapoints', @_);
+}
+
+sub _get_info{
+    my $self = shift;
+    my $id = shift;
 
     if ( @_ % 2 != 0 ) {
         warn "wrong arg count to get_average_price";
     }
     my %params = @_;
-
     foreach my $required ( qw(listing_type range) ) {
         if ( ! exists $params{$required} ) {
             warn "required paramter $required not given\n";
@@ -101,13 +117,12 @@ sub get_average_price {
     my $metadata_date = $self->_get_metadata_date($metadata_name, %params);
 
     if (defined $metadata_name && defined $metadata_date) {
-        return $self->{'metadata'}{$metadata_name}{'data'}{$metadata_date}{'avg_price'};
-    }
-    else {
-        return;
+        return $self->{'metadata'}{$metadata_name}{'data'}{$metadata_date}{$id};
     }
+    return;
 }
 
+
 sub _get_metadata_name {
     my $self = shift;
     my %params = @_;
@@ -121,9 +136,7 @@ sub _get_metadata_name {
     }
 
     $name .= "property_";
-
     $name .= $params{'listing_type'} . "_";
-
     $name .= $params{'range'};
 
     if ($params{'per_sqm'}) {
@@ -134,15 +147,34 @@ sub _get_metadata_name {
 }
 
 my %short_months = (
-    Jan => 1, Feb => 2, Mar => 3, Apr => 4,
-    May => 5, Jun => 6, Jul => 7, Aug => 8,
-    Sep => 9, Oct => 10, Nov => 11, Dec => 12
+    Jan => 1, 
+    Feb => 2, 
+    Mar => 3, 
+    Apr => 4,
+    May => 5, 
+    Jun => 6, 
+    Jul => 7, 
+    Aug => 8,
+    Sep => 9, 
+    Sept => 9, 
+    Oct => 10, 
+    Nov => 11, 
+    Dec => 12
 );
 
 my %long_months = (
-    January => 1, February => 2, March => 3, April => 4,
-    May => 5, June => 6, July => 7, August => 8,
-    September => 9, October => 10, November => 11, December => 12
+    January   => 1, 
+    February  => 2, 
+    March     => 3, 
+    April     => 4,
+    May       => 5, 
+    June      => 6, 
+    July      => 7, 
+    August    => 8,
+    September => 9, 
+    October   => 10, 
+    November  => 11, 
+    December  => 12
 );
 
 sub _get_metadata_date {
